/*****************************************************************************
 *  @file grammar/varass.c
 *  Functions for scanning/parsing files containing variable assignments.
 *
 *  Copyright (c) 2012 The fli4l team
 *
 *  This file is part of fli4l.
 *
 *  fli4l is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  fli4l is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with fli4l.  If not, see <http://www.gnu.org/licenses/>.
 *
 *  Last Update: $Id: varass.c 23640 2012-09-11 08:21:24Z kristov $
 *****************************************************************************
 */

#include <stddef.h>
#include <stdlib.h>
#include <string.h>
#include "grammar/common.h"
#include "grammar/varass.h"

struct varass_t *
varass_create(
    struct identifier_t *id,
    struct qstr_t *value,
    int priority,
    char *comment,
    struct location_t *location
)
{
    struct varass_t *ass = (struct varass_t *) malloc(sizeof(struct varass_t));
    ass->id = id;
    ass->value = value;
    ass->priority = priority;
    ass->comment = comment;
    ass->location = location;
    ass->valid = id->valid && value->valid;
    return ass;
}

void
varass_destroy(struct varass_t *ass)
{
    if (ass) {
        identifier_destroy(ass->id);
        qstr_destroy(ass->value);
        free(ass->comment);
        location_destroy(ass->location);
        free(ass);
    }
}

struct varass_parse_tree_t *
varass_parse_tree_create(void)
{
    struct varass_parse_tree_t *tree = (struct varass_parse_tree_t *)
        malloc(sizeof(struct varass_parse_tree_t));
    tree->ok = TRUE;
    tree->assignments = init_array(1024);
    return tree;
}

void
varass_parse_tree_add_assignment(
    struct varass_parse_tree_t *tree,
    struct varass_t *ass
)
{
    append_new_elem(tree->assignments, ass);
    if (!ass->valid) {
        tree->ok = FALSE;
    }
}

void
varass_parse_tree_destroy(struct varass_parse_tree_t *tree)
{
    ARRAY_ITER(it, tree->assignments, ass, struct varass_t) {
        varass_destroy(ass);
    }
    free_array(tree->assignments);
    free(tree);
}
