/*----------------------------------------------------------------------------
 *  var.h - functions for processing variables
 *
 *  Copyright (c) 2001 - Frank Meyer
 *  Copyright (c) 2001-2014 - fli4l-Team <team@fli4l.de>
 *
 *  This file is part of fli4l.
 *
 *  fli4l is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  fli4l is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with fli4l.  If not, see <http://www.gnu.org/licenses/>.
 *
 *  Creation:    2001-08-12  fm
 *  Last Update: $Id: var.h 34688 2014-11-07 12:56:15Z florian $
 *----------------------------------------------------------------------------
 */

#ifndef LIBMKFLI4L_VAR_H_
#define LIBMKFLI4L_VAR_H_

#include "defs.h"

#define MAX_FILENAMES           1024                /* max. 1024 filenames  */
#define MAX_VARIABLES           2048                /* max. 1024 variables  */
#define VAR_SIZE                128                 /* variable size        */

#define TYPE_UNKNOWN            0
#define TYPE_NUMERIC            1

void free_variables (void);

int     mark_var_requested(char const *name);
int     mark_var_copied(char const *name);
int     mark_var_tagged(char const *name);
int     mark_var_checked(char const *name);
int     mark_var_numeric(char const *name);
int     mark_var_generated(char const *name);
int     mark_var_provide(char const *name);

BOOL    is_var_tagged(char const *name);
BOOL    is_var_checked(char const *name);
BOOL    is_var_numeric(char const *name);
BOOL    is_var_weak(char const *name);
BOOL    is_var_generated(char const *name);
BOOL    is_var_copy_pending(char const *name);
BOOL    is_var_unique(char const *name, char const *file, int line);
BOOL    is_var_provide(char const *name);
BOOL    is_var_enabled(char const *name, char const *opt_var, int neg);

void    var_add_weak_declaration(char const *package, char const *name, char const *value,
                                 char const *comment, int type, char const *file,
                                 int line, int log_level);

int             check_variables(void);
int             dump_variables(char const *fname, char const *fname_full_cfg);
extern char const *get_variable(char const *);
extern char const *get_variable_package(char const *name);
extern char const *get_variable_comment(char const *);
extern void     get_variable_src(char const *name, char **src, int *line);

extern int      chkvar(char const *, char const *, char const *, char const *, BOOL, int, int, char const *);
extern int      chkvar_idx(char const *, char const *, char const *, char const *, char const *, char const *,
                           int, int, BOOL);
struct iter_t;
struct iter_t * init_set_var_iteration(char const *set_var, char const *opt_var, int neg);
char *          get_next_set_var(struct iter_t *iter, int *enabled);
int             get_last_index(struct iter_t *iter);
void            end_set_var_iteration(struct iter_t *iter);

extern void     var_init(void);
extern int      read_config_file(char const *, char const *, BOOL def);
extern int      set_variable_content(char const *, char const *);
extern int      set_variable(char const *package, char const *name,
                             char const *content, char const *comment,
                             BOOL supersede, char const *config_file,
                             BOOL dq, int line);

#endif
