/*****************************************************************************
 *  @file test_package_location.c
 *  Functions for testing locations.
 *
 *  Copyright (c) 2012 The fli4l team
 *
 *  This file is part of fli4l.
 *
 *  fli4l is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  fli4l is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with fli4l.  If not, see <http://www.gnu.org/licenses/>.
 *
 *  Last Update: $Id: test_package_location.c 23499 2012-08-29 20:28:27Z kristov $
 *****************************************************************************
 */

#include <testing/tests.h>
#include <package.h>
#include <libmkfli4l/str.h>
#include <stdlib.h>
#include <string.h>

#define MU_TESTSUITE "package.location"

/**
 * Tests location_toString() on a regular location.
 */
mu_test_begin(test_package_location_toString)
    char *value;
    struct package_t *package;
    struct package_file_t *file;
    struct location_t *location;
    char *locstr;
    char *s;

    package_init_module();
    package = package_add("myfile");
    package_set_file(package, PACKAGE_FILE_TYPE_CONFIG, "config/myfile.txt");
    file = package_get_file(package, PACKAGE_FILE_TYPE_CONFIG);
    location = location_create(file, 42, 3);
    value = location_toString(location);
    locstr = package_file_to_string(file);
    s = safe_sprintf("[%s 42:3]", locstr);
    free(locstr);
    mu_assert_eq_str(s, value);
    free(s);
    free(value);
    location_destroy(location);
    package_fini_module();
mu_test_end()

/**
 * Tests location_toString() on an internal location.
 */
mu_test_begin(test_package_location_internal_toString)
    char *value;
    struct location_t *location;
    char *locstr;
    char *s;

    package_init_module();
    location = location_create_internal(PACKAGE_FILE_TYPE_EXTCHECK);
    value = location_toString(location);
    locstr = package_file_to_string(package_get_file(package_get_internal(),
            PACKAGE_FILE_TYPE_EXTCHECK));
    s = safe_sprintf("[%s 0:0]", locstr);
    free(locstr);
    mu_assert_eq_str(s, value);
    free(s);
    free(value);
    location_destroy(location);
    package_fini_module();
mu_test_end()

/**
 * Tests location_get_package_file() on a regular location.
 */
mu_test_begin(test_package_location_get_package_file)
    struct package_t *package;
    struct package_file_t *file;
    struct location_t *location;

    package_init_module();
    package = package_add("myfile");
    package_set_file(package, PACKAGE_FILE_TYPE_CONFIG, "config/myfile.txt");
    file = package_get_file(package, PACKAGE_FILE_TYPE_CONFIG);
    location = location_create(file, 42, 3);

    mu_assert(file == location_get_package_file(location));

    location_destroy(location);
    package_fini_module();
mu_test_end()

/**
 * Tests location_get_package_file() on an internal location.
 */
mu_test_begin(test_package_location_internal_get_package_file)
    struct package_file_t *file;
    struct location_t *location;

    package_init_module();
    location = location_create_internal(PACKAGE_FILE_TYPE_EXTCHECK);
    file = package_get_file(package_get_internal(), PACKAGE_FILE_TYPE_EXTCHECK);

    mu_assert(file == location_get_package_file(location));

    location_destroy(location);
    package_fini_module();
mu_test_end()

void
test_package_location(void)
{
    mu_run_test(test_package_location_toString);
    mu_run_test(test_package_location_internal_toString);
    mu_run_test(test_package_location_get_package_file);
    mu_run_test(test_package_location_internal_get_package_file);
}
