/*****************************************************************************
 *  @file var/scope.h
 *  Functions for processing variable scopes (private interface).
 *
 *  Copyright (c) 2000-2001 - Frank Meyer
 *  Copyright (c) 2001-2014 - fli4l-Team <team@fli4l.de>
 *
 *  This file is part of fli4l.
 *
 *  fli4l is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  fli4l is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with fli4l.  If not, see <http://www.gnu.org/licenses/>.
 *
 *  Last Update: $Id: scope.h 34688 2014-11-07 12:56:15Z florian $
 *****************************************************************************
 */

#ifndef MKFLI4L_VAR_SCOPE_H_
#define MKFLI4L_VAR_SCOPE_H_

#include <libmkfli4l/defs.h>
#include <var.h>
#include <package.h>
#include <container/hashmap.h>

/**
 * Describes a variable scope.
 */
struct var_scope_t {
    /**
     * The location pointing to the beginning of the scope.
     */
    struct location_t *location;
    /**
     * The parent scope. If NULL, then this is the global scope.
     */
    struct var_scope_t *parent;
    /**
     * The variables defined in this scope.
     */
    struct hashmap_t *vars;
};

/**
 * Initializes the scope module.
 */
void
var_scope_init(void);

/**
 * Finalizes the scope module.
 */
void
var_scope_fini(void);

/**
 * Adds a variable to a scope.
 *
 * @param THIS
 *  The scope.
 * @param var
 *  The variable to add.
 * @return
 *  TRUE if addition was successful, FALSE otherwise.
 */
BOOL
var_scope_add(struct var_scope_t *THIS, struct var_t *var);

#endif
