/*****************************************************************************
 *  @file var/slot.c
 *  Functions for processing variable slots.
 *
 *  Copyright (c) 2000-2001 - Frank Meyer
 *  Copyright (c) 2001-2014 - fli4l-Team <team@fli4l.de>
 *
 *  This file is part of fli4l.
 *
 *  fli4l is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  fli4l is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with fli4l.  If not, see <http://www.gnu.org/licenses/>.
 *
 *  Last Update: $Id: slot.c 34688 2014-11-07 12:56:15Z florian $
 *****************************************************************************
 */

#include <libmkfli4l/defs.h>
#include <libmkfli4l/str.h>
#include <libmkfli4l/log.h>
#include <stdlib.h>
#include "core.h"
#include "slot.h"

#define MODULE "var::slot"

void
var_slot_init(union varslot_t *THIS, int level, int maxlevel)
{
    if (level == maxlevel) {
        THIS->entry.value = NULL;
        THIS->entry.priority = VAR_PRIORITY_UNDEFINED;
        THIS->entry.checked = FALSE;
        THIS->entry.read_active = FALSE;
    }
    else {
        THIS->array.num_slots = 0;
        THIS->array.slots = NULL;
    }
}

void
var_slot_destroy(union varslot_t *THIS, int level, int maxlevel)
{
    if (level == maxlevel) {
        free(THIS->entry.value);
    }
    else {
        unsigned i;
        for (i = 0; i < THIS->array.num_slots; ++i) {
            var_slot_destroy(&THIS->array.slots[i], level + 1, maxlevel);
        }
        free(THIS->array.slots);
        THIS->array.slots = NULL;
        THIS->array.num_slots = 0;
    }
}

char const *
var_slot_get_value(union varslot_t const *THIS, struct var_t const *var)
{
    if (THIS->entry.value) {
        return THIS->entry.value;
    }
    else if (var->props->def_value) {
        return var->props->def_value;
    }
    else {
        return NULL;
    }
}
