/*****************************************************************************
 *  @file var/slot_read.h
 *  Functions for reading from variable slots (private interface).
 *
 *  Copyright (c) 2000-2001 - Frank Meyer
 *  Copyright (c) 2001-2014 - fli4l-Team <team@fli4l.de>
 *
 *  This file is part of fli4l.
 *
 *  fli4l is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  fli4l is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with fli4l.  If not, see <http://www.gnu.org/licenses/>.
 *
 *  Last Update: $Id: slot_read.h 34688 2014-11-07 12:56:15Z florian $
 *****************************************************************************
 */

#ifndef MKFLI4L_VAR_SLOT_READ_H_
#define MKFLI4L_VAR_SLOT_READ_H_

#include <libmkfli4l/defs.h>
#include <vartype.h>
#include <var.h>
#include "slot.h"

/**
 * Returns a pointer to some variable slot for reading.
 *
 * @param THIS
 *  The variable instance addressing the slot. Excessive indices are flagged as
 *  an error, missing indices are allowed to address an array slot.
 * @param warn
 *  If TRUE, warn about indices which are out of bounds.
 * @return
 *  The variable slot or NULL if an error occurred (e.g. if array indices were
 *  out of bounds).
 */
union varslot_t *
var_instance_get_slot_for_reading(
    struct var_instance_t *THIS,
    BOOL warn
);

#endif
