/*****************************************************************************
 *  @file var/slot_write.h
 *  Functions for writing into variable slots (private interface).
 *
 *  Copyright (c) 2000-2001 - Frank Meyer
 *  Copyright (c) 2001-2014 - fli4l-Team <team@fli4l.de>
 *
 *  This file is part of fli4l.
 *
 *  fli4l is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  fli4l is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with fli4l.  If not, see <http://www.gnu.org/licenses/>.
 *
 *  Last Update: $Id: slot_write.h 34688 2014-11-07 12:56:15Z florian $
 *****************************************************************************
 */

#ifndef MKFLI4L_VAR_SLOT_READ_H_
#define MKFLI4L_VAR_SLOT_READ_H_

#include <libmkfli4l/defs.h>
#include <vartype.h>
#include <var.h>
#include "slot.h"

/**
 * Returns a pointer to some variable slot for writing. If the indices are out
 * of bounds, the array(s) are resized such that the indices lie within the
 * array bounds again. This function also updates the array bound variables
 * when some (sub)array is resized.
 *
 * @param THIS
 *  The variable instance addressing the slot. Excessive indices are flagged as
 *  an error, missing indices are allowed to address an array slot.
 * @param mode
 *  The access mode, expressed by some VAR_ACCESS_* constant.
 * @param priority
 *  The priority of the value being set.
 * @param access_failed
 *  Points to a Boolean variable which is set to TRUE on exit if functions
 *  fails because access mode and priority do not allow the slot to be changed.
 * @return
 *  The variable slot or NULL if an error occurred (e.g. if updating the array
 *  bound variables after resizing failed). NULL is also returned if access
 *  is rejected; to distinguish this case from an error condition, you have to
 *  check *access_failed.
 */
union varslot_t *
var_instance_get_slot_for_writing(
    struct var_instance_t *THIS,
    int mode,
    int priority,
    BOOL *access_failed
);

#endif
