/*****************************************************************************
 *  @file test_var_slot_aray.c
 *  Functions for testing array variable slots.
 *
 *  Copyright (c) 2012 The fli4l team
 *
 *  This file is part of fli4l.
 *
 *  fli4l is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  fli4l is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with fli4l.  If not, see <http://www.gnu.org/licenses/>.
 *
 *  Last Update: $Id: test_var_slot_array.c 24261 2012-11-05 19:38:01Z kristov $
 *****************************************************************************
 */

#include <testing/tests.h>
#include <var.h>
#include <expression/expr_literal.h>
#include <libmkfli4l/str.h>
#include <libmkfli4l/log.h>
#include <stdlib.h>
#include <string.h>

#define MU_TESTSUITE "var.slot.array"

/**
 * Tests writing to and reading from a two-dimensional array variable without
 * holes.
 */
mu_test_begin(test_var_slot_rw_array1)
    struct vartype_t *type;
    struct var_properties_t *props;
    struct var_t *var;
    struct var_instance_t *inst;
    struct var_value_t *value;

    package_init_module();
    vartype_init_module();
    var_init_module();
    type = vartype_add("MyType", "(RE:" VARTYPE_PREDEFINED_UNSIGNED_INTEGER ")", "number expected", NULL, test_location_create(PACKAGE_FILE_TYPE_VARTYPE, 42));
    vartype_finalize_type_system();
    props = var_properties_create();
    var = var_add(var_get_global_scope(), "V_%_%", type, test_location_create(PACKAGE_FILE_TYPE_VARDEF, 23), props);

    inst = var_instance_create(var, 2, NULL);
    inst->indices[0] = 0;
    inst->indices[1] = 1;
    mu_assert(var_instance_set_and_check_value(inst, "1", VAR_ACCESS_STRONG, VAR_PRIORITY_CONFIGURATION));
    inst->indices[0] = 0;
    inst->indices[1] = 0;
    mu_assert(var_instance_set_and_check_value(inst, "0", VAR_ACCESS_STRONG, VAR_PRIORITY_CONFIGURATION));
    inst->indices[0] = 1;
    inst->indices[1] = 1;
    mu_assert(var_instance_set_and_check_value(inst, "11", VAR_ACCESS_STRONG, VAR_PRIORITY_CONFIGURATION));
    inst->indices[0] = 1;
    inst->indices[1] = 0;
    mu_assert(var_instance_set_and_check_value(inst, "10", VAR_ACCESS_STRONG, VAR_PRIORITY_CONFIGURATION));

    inst->indices[0] = 0;
    inst->indices[1] = 0;
    value = var_instance_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("0", value->value);
    var_value_destroy(value);
    inst->indices[0] = 0;
    inst->indices[1] = 1;
    value = var_instance_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("1", value->value);
    var_value_destroy(value);

    inst->indices[0] = 1;
    inst->indices[1] = 0;
    value = var_instance_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("10", value->value);
    var_value_destroy(value);
    inst->indices[0] = 1;
    inst->indices[1] = 1;
    value = var_instance_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("11", value->value);
    var_value_destroy(value);
    var_instance_destroy(inst);

    var = var_get("V_N");
    mu_assert(var);
    inst = var_instance_create(var, 0, NULL);
    value = var_instance_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("2", value->value);
    var_value_destroy(value);
    var_instance_destroy(inst);

    var = var_get("V_%_N");
    mu_assert(var);
    inst = var_instance_create(var, 1, NULL);

    inst->indices[0] = 0;
    value = var_instance_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("2", value->value);
    var_value_destroy(value);
    inst->indices[0] = 1;
    value = var_instance_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("2", value->value);
    var_value_destroy(value);
    var_instance_destroy(inst);

    mu_assert(var_check_values());

    var_fini_module();
    vartype_fini_module();
    package_fini_module();
mu_test_end()

/**
 * Tests writing to and reading from a two-dimensional array variable with
 * holes.
 */
mu_test_begin(test_var_slot_rw_array2)
    struct vartype_t *type;
    struct var_properties_t *props;
    struct var_t *var;
    struct var_instance_t *inst;
    struct var_value_t *value;

    package_init_module();
    vartype_init_module();
    var_init_module();
    type = vartype_add("MyType", "(RE:" VARTYPE_PREDEFINED_UNSIGNED_INTEGER ")", "number expected", NULL, test_location_create(PACKAGE_FILE_TYPE_VARTYPE, 42));
    props = var_properties_create();
    vartype_finalize_type_system();
    var = var_add(var_get_global_scope(), "V_%_%", type, test_location_create(PACKAGE_FILE_TYPE_VARDEF, 23), props);
    inst = var_instance_create(var, 2, NULL);

    inst->indices[0] = 0;
    inst->indices[1] = 0;
    mu_assert(var_instance_set_and_check_value(inst, "0", VAR_ACCESS_STRONG, VAR_PRIORITY_CONFIGURATION));
    inst->indices[0] = 0;
    inst->indices[1] = 2;
    mu_assert(var_instance_set_and_check_value(inst, "2", VAR_ACCESS_STRONG, VAR_PRIORITY_CONFIGURATION));
    inst->indices[0] = 2;
    inst->indices[1] = 1;
    mu_assert(var_instance_set_and_check_value(inst, "21", VAR_ACCESS_STRONG, VAR_PRIORITY_CONFIGURATION));
    inst->indices[0] = 2;
    inst->indices[1] = 3;
    mu_assert(var_instance_set_and_check_value(inst, "23", VAR_ACCESS_STRONG, VAR_PRIORITY_CONFIGURATION));

    inst->indices[0] = 0;
    inst->indices[1] = 0;
    value = var_instance_try_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("0", value->value);
    var_value_destroy(value);
    value = var_instance_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("0", value->value);
    var_value_destroy(value);
    inst->indices[0] = 0;
    inst->indices[1] = 1;
    mu_assert(!var_instance_try_get_value(inst));
    mu_assert(!var_instance_get_value(inst));
    inst->indices[0] = 0;
    inst->indices[1] = 2;
    value = var_instance_try_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("2", value->value);
    var_value_destroy(value);
    value = var_instance_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("2", value->value);
    var_value_destroy(value);
    inst->indices[0] = 0;
    inst->indices[1] = 3;
    mu_assert(!var_instance_try_get_value(inst));
    mu_assert(!var_instance_get_value(inst));

    inst->indices[0] = 1;
    inst->indices[1] = 0;
    mu_assert(!var_instance_try_get_value(inst));
    mu_assert(!var_instance_get_value(inst));

    inst->indices[0] = 2;
    inst->indices[1] = 0;
    mu_assert(!var_instance_try_get_value(inst));
    mu_assert(!var_instance_get_value(inst));
    inst->indices[0] = 2;
    inst->indices[1] = 1;
    value = var_instance_try_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("21", value->value);
    var_value_destroy(value);
    value = var_instance_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("21", value->value);
    var_value_destroy(value);
    inst->indices[0] = 2;
    inst->indices[1] = 2;
    mu_assert(!var_instance_try_get_value(inst));
    mu_assert(!var_instance_get_value(inst));
    inst->indices[0] = 2;
    inst->indices[1] = 3;
    value = var_instance_try_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("23", value->value);
    var_value_destroy(value);
    value = var_instance_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("23", value->value);
    var_value_destroy(value);
    var_instance_destroy(inst);

    var = var_get("V_N");
    mu_assert(var);
    inst = var_instance_create(var, 0, NULL);
    value = var_instance_try_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("3", value->value);
    var_value_destroy(value);
    value = var_instance_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("3", value->value);
    var_value_destroy(value);
    var_instance_destroy(inst);

    var = var_get("V_%_N");
    mu_assert(var);
    inst = var_instance_create(var, 1, NULL);

    inst->indices[0] = 0;
    value = var_instance_try_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("3", value->value);
    var_value_destroy(value);
    value = var_instance_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("3", value->value);
    var_value_destroy(value);
    inst->indices[0] = 1;
    value = var_instance_try_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("0", value->value);
    var_value_destroy(value);
    value = var_instance_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("0", value->value);
    var_value_destroy(value);
    inst->indices[0] = 2;
    value = var_instance_try_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("4", value->value);
    var_value_destroy(value);
    value = var_instance_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("4", value->value);
    var_value_destroy(value);
    var_instance_destroy(inst);

    mu_assert(!var_check_values());

    var_fini_module();
    vartype_fini_module();
    package_fini_module();
mu_test_end()

/**
 * Tests writing correct but unchecked values to a two-dimensional array
 * variable without holes and checking them later.
 */
mu_test_begin(test_var_slot_rw_array_unchecked1)
    struct vartype_t *type;
    struct var_properties_t *props;
    struct var_t *var;
    struct var_instance_t *inst;
    struct var_value_t *value;

    package_init_module();
    vartype_init_module();
    var_init_module();
    type = vartype_add("MyType", "(RE:" VARTYPE_PREDEFINED_UNSIGNED_INTEGER ")", "number expected", NULL, test_location_create(PACKAGE_FILE_TYPE_VARTYPE, 42));
    vartype_finalize_type_system();
    props = var_properties_create();
    var = var_add(var_get_global_scope(), "V_%_%", type, test_location_create(PACKAGE_FILE_TYPE_VARDEF, 23), props);
    inst = var_instance_create(var, 2, NULL);

    inst->indices[0] = 0;
    inst->indices[1] = 1;
    mu_assert(var_instance_set_value(inst, "1", VAR_ACCESS_STRONG, VAR_PRIORITY_CONFIGURATION));
    inst->indices[0] = 0;
    inst->indices[1] = 0;
    mu_assert(var_instance_set_value(inst, "0", VAR_ACCESS_STRONG, VAR_PRIORITY_CONFIGURATION));
    inst->indices[0] = 1;
    inst->indices[1] = 1;
    mu_assert(var_instance_set_value(inst, "11", VAR_ACCESS_STRONG, VAR_PRIORITY_CONFIGURATION));
    inst->indices[0] = 1;
    inst->indices[1] = 0;
    mu_assert(var_instance_set_value(inst, "10", VAR_ACCESS_STRONG, VAR_PRIORITY_CONFIGURATION));

    inst->indices[0] = 0;
    inst->indices[1] = 0;
    value = var_instance_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("0", value->value);
    var_value_destroy(value);
    inst->indices[0] = 0;
    inst->indices[1] = 1;
    value = var_instance_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("1", value->value);
    var_value_destroy(value);

    inst->indices[0] = 1;
    inst->indices[1] = 0;
    value = var_instance_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("10", value->value);
    var_value_destroy(value);
    inst->indices[0] = 1;
    inst->indices[1] = 1;
    value = var_instance_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("11", value->value);
    var_value_destroy(value);
    var_instance_destroy(inst);

    var = var_get("V_N");
    mu_assert(var);
    inst = var_instance_create(var, 0, NULL);
    value = var_instance_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("2", value->value);
    var_value_destroy(value);
    var_instance_destroy(inst);

    var = var_get("V_%_N");
    mu_assert(var);
    inst = var_instance_create(var, 1, NULL);

    inst->indices[0] = 0;
    value = var_instance_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("2", value->value);
    var_value_destroy(value);
    inst->indices[0] = 1;
    value = var_instance_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("2", value->value);
    var_value_destroy(value);
    var_instance_destroy(inst);

    mu_assert(var_check_values());

    var_fini_module();
    vartype_fini_module();
    package_fini_module();
mu_test_end()

/**
 * Tests writing incorrect and unchecked values to a two-dimensional array
 * variable without holes and checking them later.
 */
mu_test_begin(test_var_slot_rw_array_unchecked2)
    struct vartype_t *type;
    struct var_properties_t *props;
    struct var_t *var;
    struct var_instance_t *inst;
    struct var_value_t *value;

    package_init_module();
    vartype_init_module();
    var_init_module();
    type = vartype_add("MyType", "(RE:" VARTYPE_PREDEFINED_UNSIGNED_INTEGER ")", "number expected", NULL, test_location_create(PACKAGE_FILE_TYPE_VARTYPE, 42));
    vartype_finalize_type_system();
    props = var_properties_create();
    var = var_add(var_get_global_scope(), "V_%_%", type, test_location_create(PACKAGE_FILE_TYPE_VARDEF, 23), props);
    inst = var_instance_create(var, 2, NULL);

    inst->indices[0] = 0;
    inst->indices[1] = 1;
    mu_assert(var_instance_set_value(inst, "A", VAR_ACCESS_STRONG, VAR_PRIORITY_CONFIGURATION));
    inst->indices[0] = 0;
    inst->indices[1] = 0;
    mu_assert(var_instance_set_value(inst, "B", VAR_ACCESS_STRONG, VAR_PRIORITY_CONFIGURATION));
    inst->indices[0] = 1;
    inst->indices[1] = 1;
    mu_assert(var_instance_set_value(inst, "AA", VAR_ACCESS_STRONG, VAR_PRIORITY_CONFIGURATION));
    inst->indices[0] = 1;
    inst->indices[1] = 0;
    mu_assert(var_instance_set_value(inst, "BB", VAR_ACCESS_STRONG, VAR_PRIORITY_CONFIGURATION));

    inst->indices[0] = 0;
    inst->indices[1] = 0;
    value = var_instance_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("B", value->value);
    var_value_destroy(value);
    inst->indices[0] = 0;
    inst->indices[1] = 1;
    value = var_instance_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("A", value->value);
    var_value_destroy(value);

    inst->indices[0] = 1;
    inst->indices[1] = 0;
    value = var_instance_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("BB", value->value);
    var_value_destroy(value);
    inst->indices[0] = 1;
    inst->indices[1] = 1;
    value = var_instance_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("AA", value->value);
    var_value_destroy(value);
    var_instance_destroy(inst);

    var = var_get("V_N");
    mu_assert(var);
    inst = var_instance_create(var, 0, NULL);
    value = var_instance_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("2", value->value);
    var_value_destroy(value);
    var_instance_destroy(inst);

    var = var_get("V_%_N");
    mu_assert(var);
    inst = var_instance_create(var, 1, NULL);

    inst->indices[0] = 0;
    value = var_instance_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("2", value->value);
    var_value_destroy(value);
    inst->indices[0] = 1;
    value = var_instance_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("2", value->value);
    var_value_destroy(value);
    var_instance_destroy(inst);

    mu_assert(!var_check_values());

    var_fini_module();
    vartype_fini_module();
    package_fini_module();
mu_test_end()

/**
 * Tests writing to and reading from two one-dimensional array variables
 * sharing the array bound variable.
 */
mu_test_begin(test_var_slot_rw_array_multi)
    struct vartype_t *type;
    struct var_t *var1;
    struct var_t *var2;
    struct var_t *var_n;
    struct var_instance_t *inst1;
    struct var_instance_t *inst2;
    struct var_instance_t *inst_n;
    struct var_value_t *value;

    package_init_module();
    vartype_init_module();
    var_init_module();
    type = vartype_add("MyType", "(RE:" VARTYPE_PREDEFINED_UNSIGNED_INTEGER ")", "number expected", NULL, test_location_create(PACKAGE_FILE_TYPE_VARTYPE, 42));
    vartype_finalize_type_system();
    var1 = var_add(var_get_global_scope(), "V_%_A", type, test_location_create(PACKAGE_FILE_TYPE_VARDEF, 23), var_properties_create());
    var2 = var_add(var_get_global_scope(), "V_%_B", type, test_location_create(PACKAGE_FILE_TYPE_VARDEF, 24), var_properties_create());
    inst1 = var_instance_create(var1, 1, NULL);
    inst2 = var_instance_create(var2, 1, NULL);

    inst1->indices[0] = 0;
    mu_assert(var_instance_set_and_check_value(inst1, "0", VAR_ACCESS_STRONG, VAR_PRIORITY_CONFIGURATION));
    inst2->indices[0] = 1;
    mu_assert(var_instance_set_and_check_value(inst2, "1", VAR_ACCESS_STRONG, VAR_PRIORITY_CONFIGURATION));

    inst1->indices[0] = 0;
    value = var_instance_get_value(inst1);
    mu_assert(value);
    mu_assert_eq_str("0", value->value);
    var_value_destroy(value);
    inst2->indices[0] = 0;
    mu_assert(!var_instance_get_value(inst2));

    inst1->indices[0] = 1;
    mu_assert(!var_instance_get_value(inst1));
    inst2->indices[0] = 1;
    value = var_instance_get_value(inst2);
    mu_assert(value);
    mu_assert_eq_str("1", value->value);
    var_value_destroy(value);

    var_n = var_get("V_N");
    mu_assert(var_n);
    inst_n = var_instance_create(var_n, 0, NULL);
    value = var_instance_get_value(inst_n);
    mu_assert(value);
    mu_assert_eq_str("2", value->value);
    var_value_destroy(value);
    var_instance_destroy(inst_n);

    mu_assert(!var_check_values());

    var_instance_destroy(inst2);
    var_instance_destroy(inst1);
    var_fini_module();
    vartype_fini_module();
    package_fini_module();
mu_test_end()

/**
 * Tests writing to and reading from a two-dimensional array variable with
 * user-defined bounds.
 */
mu_test_begin(test_var_slot_rw_array_user_defined_bounds1)
    struct vartype_t *type;
    struct var_properties_t *props;
    struct var_t *var;
    struct var_t *var_n;
    struct var_instance_t *inst;
    struct var_value_t *value;

    package_init_module();
    vartype_init_module();
    var_init_module();
    type = vartype_add("MyType", "(RE:" VARTYPE_PREDEFINED_UNSIGNED_INTEGER ")", "number expected", NULL, test_location_create(PACKAGE_FILE_TYPE_VARTYPE, 42));
    vartype_finalize_type_system();
    props = var_properties_create();
    var = var_add(var_get_global_scope(), "V_%_%", type, test_location_create(PACKAGE_FILE_TYPE_VARDEF, 23), props);

    var_n = var_get("V_N");
    mu_assert(var_n);
    inst = var_instance_create(var_n, 0, NULL);
    mu_assert(var_instance_set_and_check_value(inst, "1", VAR_ACCESS_STRONG, VAR_PRIORITY_CONFIGURATION));
    var_instance_destroy(inst);
    var_n = var_get("V_%_N");
    mu_assert(var_n);
    inst = var_instance_create(var_n, 1, NULL);
    inst->indices[0] = 0;
    mu_assert(var_instance_set_and_check_value(inst, "1", VAR_ACCESS_STRONG, VAR_PRIORITY_CONFIGURATION));
    var_instance_destroy(inst);

    inst = var_instance_create(var, 2, NULL);
    inst->indices[0] = 0;
    inst->indices[1] = 1;
    mu_assert(var_instance_set_and_check_value(inst, "1", VAR_ACCESS_STRONG, VAR_PRIORITY_CONFIGURATION));
    inst->indices[0] = 0;
    inst->indices[1] = 0;
    mu_assert(var_instance_set_and_check_value(inst, "0", VAR_ACCESS_STRONG, VAR_PRIORITY_CONFIGURATION));
    inst->indices[0] = 1;
    inst->indices[1] = 1;
    mu_assert(var_instance_set_and_check_value(inst, "11", VAR_ACCESS_STRONG, VAR_PRIORITY_CONFIGURATION));
    inst->indices[0] = 1;
    inst->indices[1] = 0;
    mu_assert(var_instance_set_and_check_value(inst, "10", VAR_ACCESS_STRONG, VAR_PRIORITY_CONFIGURATION));

    inst->indices[0] = 0;
    inst->indices[1] = 0;
    value = var_instance_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("0", value->value);
    var_value_destroy(value);
    inst->indices[0] = 0;
    inst->indices[1] = 1;
    value = var_instance_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("1", value->value);
    var_value_destroy(value);

    inst->indices[0] = 1;
    inst->indices[1] = 0;
    value = var_instance_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("10", value->value);
    var_value_destroy(value);
    inst->indices[0] = 1;
    inst->indices[1] = 1;
    value = var_instance_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("11", value->value);
    var_value_destroy(value);
    var_instance_destroy(inst);

    var_n = var_get("V_N");
    mu_assert(var_n);
    inst = var_instance_create(var_n, 0, NULL);
    value = var_instance_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("1", value->value);
    var_value_destroy(value);
    var_instance_destroy(inst);

    var_n = var_get("V_%_N");
    mu_assert(var_n);
    inst = var_instance_create(var_n, 1, NULL);

    inst->indices[0] = 0;
    value = var_instance_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("1", value->value);
    var_value_destroy(value);
    inst->indices[0] = 1;
    value = var_instance_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("2", value->value);
    var_value_destroy(value);
    var_instance_destroy(inst);

    mu_assert(var_check_values());

    var_fini_module();
    vartype_fini_module();
    package_fini_module();
mu_test_end()

/**
 * Tests writing to and reading from a two-dimensional array variable with
 * user-defined bounds where some values outside user-defined bounds are
 * incorrect.
 */
mu_test_begin(test_var_slot_rw_array_user_defined_bounds2)
    struct vartype_t *type;
    struct var_properties_t *props;
    struct var_t *var;
    struct var_t *var_n;
    struct var_instance_t *inst;
    struct var_value_t *value;

    package_init_module();
    vartype_init_module();
    var_init_module();
    type = vartype_add("MyType", "(RE:" VARTYPE_PREDEFINED_UNSIGNED_INTEGER ")", "number expected", NULL, test_location_create(PACKAGE_FILE_TYPE_VARTYPE, 42));
    vartype_finalize_type_system();
    props = var_properties_create();
    var = var_add(var_get_global_scope(), "V_%_%", type, test_location_create(PACKAGE_FILE_TYPE_VARDEF, 23), props);

    var_n = var_get("V_N");
    mu_assert(var_n);
    inst = var_instance_create(var_n, 0, NULL);
    mu_assert(var_instance_set_and_check_value(inst, "1", VAR_ACCESS_STRONG, VAR_PRIORITY_CONFIGURATION));
    var_instance_destroy(inst);
    var_n = var_get("V_%_N");
    mu_assert(var_n);
    inst = var_instance_create(var_n, 1, NULL);
    inst->indices[0] = 0;
    mu_assert(var_instance_set_and_check_value(inst, "1", VAR_ACCESS_STRONG, VAR_PRIORITY_CONFIGURATION));
    var_instance_destroy(inst);

    inst = var_instance_create(var, 2, NULL);
    inst->indices[0] = 0;
    inst->indices[1] = 1;
    mu_assert(var_instance_set_value(inst, "X", VAR_ACCESS_STRONG, VAR_PRIORITY_CONFIGURATION));
    inst->indices[0] = 0;
    inst->indices[1] = 0;
    mu_assert(var_instance_set_and_check_value(inst, "0", VAR_ACCESS_STRONG, VAR_PRIORITY_CONFIGURATION));
    inst->indices[0] = 1;
    inst->indices[1] = 1;
    mu_assert(var_instance_set_value(inst, "Y", VAR_ACCESS_STRONG, VAR_PRIORITY_CONFIGURATION));
    inst->indices[0] = 1;
    inst->indices[1] = 0;
    mu_assert(var_instance_set_and_check_value(inst, "10", VAR_ACCESS_STRONG, VAR_PRIORITY_CONFIGURATION));

    inst->indices[0] = 0;
    inst->indices[1] = 0;
    value = var_instance_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("0", value->value);
    var_value_destroy(value);
    inst->indices[0] = 0;
    inst->indices[1] = 1;
    value = var_instance_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("X", value->value);
    var_value_destroy(value);

    inst->indices[0] = 1;
    inst->indices[1] = 0;
    value = var_instance_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("10", value->value);
    var_value_destroy(value);
    inst->indices[0] = 1;
    inst->indices[1] = 1;
    value = var_instance_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("Y", value->value);
    var_value_destroy(value);
    var_instance_destroy(inst);

    var_n = var_get("V_N");
    mu_assert(var_n);
    inst = var_instance_create(var_n, 0, NULL);
    value = var_instance_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("1", value->value);
    var_value_destroy(value);
    var_instance_destroy(inst);

    var_n = var_get("V_%_N");
    mu_assert(var_n);
    inst = var_instance_create(var_n, 1, NULL);

    inst->indices[0] = 0;
    value = var_instance_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("1", value->value);
    var_value_destroy(value);
    inst->indices[0] = 1;
    value = var_instance_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("2", value->value);
    var_value_destroy(value);
    var_instance_destroy(inst);

    mu_assert(var_check_values());

    var_fini_module();
    vartype_fini_module();
    package_fini_module();
mu_test_end()

/**
 * Tests writing to and reading from a two-dimensional array variable with
 * user-defined bounds where some bounds are too large.
 */
mu_test_begin(test_var_slot_rw_array_user_defined_bounds3)
    struct vartype_t *type;
    struct var_t *var;
    struct var_properties_t *props;
    struct var_t *var_n;
    struct var_instance_t *inst;
    struct var_value_t *value;

    package_init_module();
    vartype_init_module();
    var_init_module();
    type = vartype_add("MyType", "(RE:" VARTYPE_PREDEFINED_UNSIGNED_INTEGER ")", "number expected", NULL, test_location_create(PACKAGE_FILE_TYPE_VARTYPE, 42));
    vartype_finalize_type_system();
    props = var_properties_create();
    var = var_add(var_get_global_scope(), "V_%_%", type, test_location_create(PACKAGE_FILE_TYPE_VARDEF, 23), props);

    var_n = var_get("V_N");
    mu_assert(var_n);
    inst = var_instance_create(var_n, 0, NULL);
    mu_assert(var_instance_set_and_check_value(inst, "3", VAR_ACCESS_STRONG, VAR_PRIORITY_CONFIGURATION));
    var_instance_destroy(inst);
    var_n = var_get("V_%_N");
    mu_assert(var_n);
    inst = var_instance_create(var_n, 1, NULL);
    inst->indices[0] = 0;
    mu_assert(var_instance_set_and_check_value(inst, "3", VAR_ACCESS_STRONG, VAR_PRIORITY_CONFIGURATION));
    var_instance_destroy(inst);

    inst = var_instance_create(var, 2, NULL);
    inst->indices[0] = 0;
    inst->indices[1] = 1;
    mu_assert(var_instance_set_and_check_value(inst, "1", VAR_ACCESS_STRONG, VAR_PRIORITY_CONFIGURATION));
    inst->indices[0] = 0;
    inst->indices[1] = 0;
    mu_assert(var_instance_set_and_check_value(inst, "0", VAR_ACCESS_STRONG, VAR_PRIORITY_CONFIGURATION));
    inst->indices[0] = 1;
    inst->indices[1] = 1;
    mu_assert(var_instance_set_and_check_value(inst, "11", VAR_ACCESS_STRONG, VAR_PRIORITY_CONFIGURATION));
    inst->indices[0] = 1;
    inst->indices[1] = 0;
    mu_assert(var_instance_set_and_check_value(inst, "10", VAR_ACCESS_STRONG, VAR_PRIORITY_CONFIGURATION));

    inst->indices[0] = 0;
    inst->indices[1] = 0;
    value = var_instance_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("0", value->value);
    var_value_destroy(value);
    inst->indices[0] = 0;
    inst->indices[1] = 1;
    value = var_instance_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("1", value->value);
    var_value_destroy(value);

    inst->indices[0] = 1;
    inst->indices[1] = 0;
    value = var_instance_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("10", value->value);
    var_value_destroy(value);
    inst->indices[0] = 1;
    inst->indices[1] = 1;
    value = var_instance_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("11", value->value);
    var_value_destroy(value);
    var_instance_destroy(inst);

    var_n = var_get("V_N");
    mu_assert(var_n);
    inst = var_instance_create(var_n, 0, NULL);
    value = var_instance_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("3", value->value);
    var_value_destroy(value);
    var_instance_destroy(inst);

    var_n = var_get("V_%_N");
    mu_assert(var_n);
    inst = var_instance_create(var_n, 1, NULL);

    inst->indices[0] = 0;
    value = var_instance_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("3", value->value);
    var_value_destroy(value);
    inst->indices[0] = 1;
    value = var_instance_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("2", value->value);
    var_value_destroy(value);
    var_instance_destroy(inst);

    mu_assert(!var_check_values());

    var_fini_module();
    vartype_fini_module();
    package_fini_module();
mu_test_end()

/**
 * Tests writing to and reading from a two-dimensional array variable with
 * user-defined bounds where some bounds are incorrect.
 */
mu_test_begin(test_var_slot_rw_array_user_defined_bounds4)
    struct vartype_t *type;
    struct var_properties_t *props;
    struct var_t *var;
    struct var_t *var_n;
    struct var_instance_t *inst;
    struct var_instance_t *inst_n;
    struct var_value_t *value;

    package_init_module();
    vartype_init_module();
    var_init_module();
    type = vartype_add("MyType", "(RE:" VARTYPE_PREDEFINED_UNSIGNED_INTEGER ")", "number expected", NULL, test_location_create(PACKAGE_FILE_TYPE_VARTYPE, 42));
    vartype_finalize_type_system();
    props = var_properties_create();
    var = var_add(var_get_global_scope(), "V_%_%", type, test_location_create(PACKAGE_FILE_TYPE_VARDEF, 23), props);

    var_n = var_get("V_N");
    mu_assert(var_n);
    inst_n = var_instance_create(var_n, 0, NULL);
    mu_assert(var_instance_set_value(inst_n, "ABC", VAR_ACCESS_WEAK, VAR_PRIORITY_SCRIPT_TRANSIENT));
    var_instance_destroy(inst_n);

    var_n = var_get("V_%_N");
    mu_assert(var_n);
    inst_n = var_instance_create(var_n, 1, NULL);
    inst_n->indices[0] = 0;
    mu_assert(!var_instance_set_value(inst_n, "-1", VAR_ACCESS_STRONG, VAR_PRIORITY_CONFIGURATION));
    mu_assert(var_instance_set_and_check_value(inst_n, "2", VAR_ACCESS_WEAK, VAR_PRIORITY_CONFIGURATION));
    var_instance_destroy(inst_n);

    var_n = var_get("V_N");
    mu_assert(var_n);
    inst_n = var_instance_create(var_n, 0, NULL);
    mu_assert(var_instance_set_and_check_value(inst_n, "2", VAR_ACCESS_STRONG, VAR_PRIORITY_CONFIGURATION));
    var_instance_destroy(inst_n);

    var_n = var_get("V_%_N");
    mu_assert(var_n);
    inst_n = var_instance_create(var_n, 1, NULL);
    inst_n->indices[0] = 0;
    mu_assert(var_instance_set_value(inst_n, "-1", VAR_ACCESS_WEAK, VAR_PRIORITY_CONFIGURATION));
    var_instance_destroy(inst_n);

    inst = var_instance_create(var, 2, NULL);
    inst->indices[0] = 0;
    inst->indices[1] = 1;
    mu_assert(var_instance_set_and_check_value(inst, "1", VAR_ACCESS_STRONG, VAR_PRIORITY_CONFIGURATION));
    inst->indices[0] = 0;
    inst->indices[1] = 0;
    mu_assert(var_instance_set_and_check_value(inst, "0", VAR_ACCESS_STRONG, VAR_PRIORITY_CONFIGURATION));
    inst->indices[0] = 1;
    inst->indices[1] = 1;
    mu_assert(var_instance_set_and_check_value(inst, "11", VAR_ACCESS_STRONG, VAR_PRIORITY_CONFIGURATION));
    inst->indices[0] = 1;
    inst->indices[1] = 0;
    mu_assert(var_instance_set_and_check_value(inst, "10", VAR_ACCESS_STRONG, VAR_PRIORITY_CONFIGURATION));

    inst->indices[0] = 0;
    inst->indices[1] = 0;
    value = var_instance_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("0", value->value);
    var_value_destroy(value);
    inst->indices[0] = 0;
    inst->indices[1] = 1;
    value = var_instance_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("1", value->value);
    var_value_destroy(value);

    inst->indices[0] = 1;
    inst->indices[1] = 0;
    value = var_instance_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("10", value->value);
    var_value_destroy(value);
    inst->indices[0] = 1;
    inst->indices[1] = 1;
    value = var_instance_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("11", value->value);
    var_value_destroy(value);
    var_instance_destroy(inst);

    var_n = var_get("V_N");
    mu_assert(var_n);
    inst = var_instance_create(var_n, 0, NULL);
    value = var_instance_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("2", value->value);
    var_value_destroy(value);
    var_instance_destroy(inst);

    var_n = var_get("V_%_N");
    mu_assert(var_n);
    inst = var_instance_create(var_n, 1, NULL);

    inst->indices[0] = 0;
    value = var_instance_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("-1", value->value);
    var_value_destroy(value);
    inst->indices[0] = 1;
    value = var_instance_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("2", value->value);
    var_value_destroy(value);
    var_instance_destroy(inst);

    mu_assert(!var_check_values());

    var_fini_module();
    vartype_fini_module();
    package_fini_module();
mu_test_end()

/**
 * Tests writing to and reading from a two-dimensional array variable with
 * user-defined bound variables without default values.
 */
mu_test_begin(test_var_slot_rw_array_user_defined_bound_var1)
    struct vartype_t *type;
    struct var_properties_t *props;
    struct var_properties_t const *propsNew;
    struct var_t *var_n1;
    struct var_t *var_n2;
    struct var_t *var_n;

    package_init_module();
    vartype_init_module();
    var_init_module();

    type = vartype_add("MyType", "(RE:" VARTYPE_PREDEFINED_UNSIGNED_INTEGER ")", "number expected", NULL, test_location_create(PACKAGE_FILE_TYPE_VARTYPE, 42));
    vartype_finalize_type_system();
    props = var_properties_create();
    var_n1 = var_add(var_get_global_scope(), "V_N", vartype_get(VARTYPE_PREDEFINED_UNSIGNED_INTEGER), test_location_create(PACKAGE_FILE_TYPE_VARDEF, 21), props);
    props = var_properties_create();
    var_n2 = var_add(var_get_global_scope(), "V_%_N", vartype_get(VARTYPE_PREDEFINED_UNSIGNED_INTEGER), test_location_create(PACKAGE_FILE_TYPE_VARDEF, 22), props);
    props = var_properties_create();
    var_add(var_get_global_scope(), "V_%_%", type, test_location_create(PACKAGE_FILE_TYPE_VARDEF, 23), props);

    var_n = var_get("V_N");
    mu_assert(var_n == var_n1);
    propsNew = var_get_properties(var_n);
    mu_assert_eq_str(propsNew->def_value, "0");

    var_n = var_get("V_%_N");
    mu_assert(var_n == var_n2);
    propsNew = var_get_properties(var_n);
    mu_assert_eq_str(propsNew->def_value, "0");

    var_fini_module();
    vartype_fini_module();
    package_fini_module();
mu_test_end()

/**
 * Tests writing to and reading from a two-dimensional array variable with
 * user-defined bound variables with default values.
 */
mu_test_begin(test_var_slot_rw_array_user_defined_bound_var2)
    struct vartype_t *type;
    struct var_properties_t *props;
    struct var_properties_t const *propsNew;
    struct var_t *var_n1;
    struct var_t *var_n2;
    struct var_t *var_n;

    package_init_module();
    vartype_init_module();
    var_init_module();

    type = vartype_add("MyType", "(RE:" VARTYPE_PREDEFINED_UNSIGNED_INTEGER ")", "number expected", NULL, test_location_create(PACKAGE_FILE_TYPE_VARTYPE, 42));
    vartype_finalize_type_system();
    props = var_properties_create();
    var_properties_set_default_value(props, "1");
    var_n1 = var_add(var_get_global_scope(), "V_N", vartype_get(VARTYPE_PREDEFINED_UNSIGNED_INTEGER), test_location_create(PACKAGE_FILE_TYPE_VARDEF, 21), props);
    props = var_properties_create();
    var_properties_set_default_value(props, "2");
    var_n2 = var_add(var_get_global_scope(), "V_%_N", vartype_get(VARTYPE_PREDEFINED_UNSIGNED_INTEGER), test_location_create(PACKAGE_FILE_TYPE_VARDEF, 22), props);
    props = var_properties_create();
    var_add(var_get_global_scope(), "V_%_%", type, test_location_create(PACKAGE_FILE_TYPE_VARDEF, 23), props);

    var_n = var_get("V_N");
    mu_assert(var_n == var_n1);
    propsNew = var_get_properties(var_n);
    mu_assert_eq_str(propsNew->def_value, "1");

    var_n = var_get("V_%_N");
    mu_assert(var_n == var_n2);
    propsNew = var_get_properties(var_n);
    mu_assert_eq_str(propsNew->def_value, "2");

    var_fini_module();
    vartype_fini_module();
    package_fini_module();
mu_test_end()

/**
 * Tests checking missing values of an optional array variable.
 */
mu_test_begin(test_var_slot_r_array_check_missing)
    struct vartype_t *type;
    struct var_properties_t *props;
    struct var_t *var;
    struct var_instance_t *inst;

    package_init_module();
    vartype_init_module();
    var_init_module();
    type = vartype_add("MyType", "(RE:" VARTYPE_PREDEFINED_UNSIGNED_INTEGER ")", "number expected", NULL, test_location_create(PACKAGE_FILE_TYPE_VARTYPE, 42));
    vartype_finalize_type_system();
    props = var_properties_create();
    props->optional = TRUE;
    var = var_add(var_get_global_scope(), "V_%", type, test_location_create(PACKAGE_FILE_TYPE_VARDEF, 23), props);
    inst = var_instance_create(var, 1, NULL);

    inst->indices[0] = 1;
    mu_assert(var_instance_set_and_check_value(inst, "42", VAR_ACCESS_STRONG, VAR_PRIORITY_CONFIGURATION));

    inst->indices[0] = 0;
    mu_assert(!var_instance_get_value(inst));
    mu_assert(var_check_values());

    var_instance_destroy(inst);
    var_fini_module();
    vartype_fini_module();
    package_fini_module();
mu_test_end()

/**
 * Tests clearing a one-dimensional array.
 */
mu_test_begin(test_var_slot_clear1)
    struct vartype_t *type;
    struct var_properties_t *props;
    struct var_t *var;
    struct var_t *var_n;
    struct var_instance_t *inst;
    struct var_instance_t *inst_n;
    struct var_value_t *value;

    package_init_module();
    vartype_init_module();
    var_init_module();
    type = vartype_add(NULL, ".*", "", NULL, test_location_create(PACKAGE_FILE_TYPE_VARTYPE, 42));
    vartype_finalize_type_system();
    props = var_properties_create();
    props->optional = TRUE;
    var = var_add(var_get_global_scope(), "MATCH_%", type, test_location_create(PACKAGE_FILE_TYPE_VARDEF, 23), props);
    inst = var_instance_create(var, 1, NULL);

    inst->indices[0] = 0;
    mu_assert(var_instance_set_and_check_value(inst, "42", VAR_ACCESS_WEAK, VAR_PRIORITY_SCRIPT_TRANSIENT));
    inst->indices[0] = 1;
    mu_assert(var_instance_set_and_check_value(inst, "23", VAR_ACCESS_WEAK, VAR_PRIORITY_SCRIPT_TRANSIENT));

    var_n = var_get("MATCH_N");
    mu_assert(var_n);
    inst_n = var_instance_create(var_n, 0, NULL);
    value = var_instance_get_value(inst_n);
    mu_assert(value);
    mu_assert_eq_str("2", value->value);
    var_value_destroy(value);

    inst->num_indices = 0;
    mu_assert(var_instance_clear(inst, VAR_ACCESS_WEAK, VAR_PRIORITY_SCRIPT_TRANSIENT));

    inst->num_indices = 1;
    inst->indices[0] = 0;
    mu_assert(!var_instance_get_value(inst));
    inst->indices[0] = 1;
    mu_assert(!var_instance_get_value(inst));

    value = var_instance_get_value(inst_n);
    mu_assert(value);
    mu_assert_eq_str("0", value->value);
    var_value_destroy(value);
    var_instance_destroy(inst_n);

    mu_assert(var_check_values());

    var_instance_destroy(inst);
    var_fini_module();
    vartype_fini_module();
    package_fini_module();
mu_test_end()

/**
 * Tests clearing a subarray of a two-dimensional array.
 */
mu_test_begin(test_var_slot_clear2)
    struct vartype_t *type;
    struct var_properties_t *props;
    struct var_t *var;
    struct var_t *var_n;
    struct var_instance_t *inst;
    struct var_instance_t *inst_n;
    struct var_value_t *value;

    package_init_module();
    vartype_init_module();
    var_init_module();
    type = vartype_add(NULL, ".*", "", NULL, test_location_create(PACKAGE_FILE_TYPE_VARTYPE, 42));
    vartype_finalize_type_system();
    props = var_properties_create();
    var = var_add(var_get_global_scope(), "V_%_%", type, test_location_create(PACKAGE_FILE_TYPE_VARDEF, 23), props);
    inst = var_instance_create(var, 2, NULL);

    inst->indices[0] = 0;
    inst->indices[1] = 0;
    mu_assert(var_instance_set_and_check_value(inst, "0", VAR_ACCESS_WEAK, VAR_PRIORITY_SCRIPT_TRANSIENT));
    inst->indices[0] = 1;
    inst->indices[1] = 1;
    mu_assert(var_instance_set_and_check_value(inst, "11", VAR_ACCESS_WEAK, VAR_PRIORITY_SCRIPT_TRANSIENT));
    inst->indices[0] = 1;
    inst->indices[1] = 0;
    mu_assert(var_instance_set_and_check_value(inst, "10", VAR_ACCESS_WEAK, VAR_PRIORITY_SCRIPT_TRANSIENT));

    var_n = var_get("V_N");
    mu_assert(var_n);
    inst_n = var_instance_create(var_n, 0, NULL);
    value = var_instance_get_value(inst_n);
    mu_assert(value);
    mu_assert_eq_str("2", value->value);
    var_value_destroy(value);
    var_instance_destroy(inst_n);

    var_n = var_get("V_%_N");
    mu_assert(var_n);
    inst_n = var_instance_create(var_n, 1, NULL);
    inst_n->indices[0] = 0;
    value = var_instance_get_value(inst_n);
    mu_assert(value);
    mu_assert_eq_str("1", value->value);
    var_value_destroy(value);
    inst_n->indices[0] = 1;
    value = var_instance_get_value(inst_n);
    mu_assert(value);
    mu_assert_eq_str("2", value->value);
    var_value_destroy(value);
    var_instance_destroy(inst_n);

    inst->num_indices = 1;
    inst->indices[0] = 0;
    mu_assert(var_instance_clear(inst, VAR_ACCESS_WEAK, VAR_PRIORITY_SCRIPT_TRANSIENT));

    inst->num_indices = 2;
    inst->indices[0] = 0;
    inst->indices[1] = 0;
    mu_assert(!var_instance_get_value(inst));
    inst->indices[0] = 0;
    inst->indices[1] = 1;
    mu_assert(!var_instance_get_value(inst));
    inst->indices[0] = 1;
    inst->indices[1] = 0;
    value = var_instance_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("10", value->value);
    var_value_destroy(value);
    inst->indices[0] = 1;
    inst->indices[1] = 1;
    value = var_instance_get_value(inst);
    mu_assert(value);
    mu_assert_eq_str("11", value->value);
    var_value_destroy(value);

    var_n = var_get("V_N");
    mu_assert(var_n);
    inst_n = var_instance_create(var_n, 0, NULL);
    value = var_instance_get_value(inst_n);
    mu_assert(value);
    mu_assert_eq_str("2", value->value);
    var_value_destroy(value);
    var_instance_destroy(inst_n);

    var_n = var_get("V_%_N");
    mu_assert(var_n);
    inst_n = var_instance_create(var_n, 1, NULL);
    inst_n->indices[0] = 0;
    value = var_instance_get_value(inst_n);
    mu_assert(value);
    mu_assert_eq_str("0", value->value);
    var_value_destroy(value);
    inst_n->indices[0] = 1;
    value = var_instance_get_value(inst_n);
    mu_assert(value);
    mu_assert_eq_str("2", value->value);
    var_value_destroy(value);
    var_instance_destroy(inst_n);

    inst->indices[0] = 1;
    inst->indices[0] = 0;
    mu_assert(!var_instance_clear(inst, VAR_ACCESS_WEAK, VAR_PRIORITY_SCRIPT_TRANSIENT));

    mu_assert(var_check_values());

    var_instance_destroy(inst);
    var_fini_module();
    vartype_fini_module();
    package_fini_module();
mu_test_end()

void
test_var_slot_array(void)
{
    set_log_level(LOG_VAR);
    mu_run_test(test_var_slot_rw_array1);
    mu_run_test(test_var_slot_rw_array2);
    mu_run_test(test_var_slot_rw_array_multi);
    mu_run_test(test_var_slot_rw_array_unchecked1);
    mu_run_test(test_var_slot_rw_array_unchecked2);
    mu_run_test(test_var_slot_rw_array_user_defined_bounds1);
    mu_run_test(test_var_slot_rw_array_user_defined_bounds2);
    mu_run_test(test_var_slot_rw_array_user_defined_bounds3);
    mu_run_test(test_var_slot_rw_array_user_defined_bounds4);
    mu_run_test(test_var_slot_rw_array_user_defined_bound_var1);
    mu_run_test(test_var_slot_rw_array_user_defined_bound_var2);
    mu_run_test(test_var_slot_r_array_check_missing);
    mu_run_test(test_var_slot_clear1);
    mu_run_test(test_var_slot_clear2);
}
